@@ -26,8 +26,9 @@ class VerifyEmailUser(VerifyEmailMixin):
     pass
 
 
-class CustomBasicUserFieldsMixin(NameUserMethodsMixin, EmailUserMixin,
-        DateJoinedUserMixin, IsStaffUserMixin):
+class CustomBasicUserFieldsMixin(
+        NameUserMethodsMixin, EmailUserMixin, DateJoinedUserMixin,
+        IsStaffUserMixin):
     name = models.TextField()
 
     USERNAME_FIELD = 'email'
@@ -36,6 +37,7 @@ class CustomBasicUserFieldsMixin(NameUserMethodsMixin, EmailUserMixin,
         abstract = True
 
 
-class CustomNameUser(AvatarMixin, EmailVerifyUserMixin, CustomBasicUserFieldsMixin,
+class CustomNameUser(
+        AvatarMixin, EmailVerifyUserMixin, CustomBasicUserFieldsMixin,
         AbstractBaseUser):
     pass
